==> qtmobility_1.1.0.orig.tar.gz: qt-mobility-opensource-src-1.1.0/plugins/multimedia/symbian/mmf/audiosource/s60audiocaptureservice.cpp <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in 
** accordance with the Qt Commercial License Agreement provided with
** the Software or, alternatively, in accordance with the terms
** contained in a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/
#include <QDebug>

#include "s60audiocaptureservice.h"
#include "s60audiocapturesession.h"
#include "s60audioendpointselector.h"
#include "s60audioencodercontrol.h"
#include "s60audiomediarecordercontrol.h"
#include "S60audiocontainercontrol.h"

S60AudioCaptureService::S60AudioCaptureService(QObject *parent):
    QMediaService(parent)
{    
    m_session = new S60AudioCaptureSession(this);
    m_encoderControl = new S60AudioEncoderControl(m_session,this);
    m_recorderControl = new S60AudioMediaRecorderControl(m_session,this);
    m_endpointSelector = new S60AudioEndpointSelector(m_session,this); 
    m_containerControl = new S60AudioContainerControl(m_session, this);
}

S60AudioCaptureService::~S60AudioCaptureService()
{
}

QMediaControl *S60AudioCaptureService::requestControl(const char *name)
{    
    if (qstrcmp(name,QMediaRecorderControl_iid) == 0)
        return m_recorderControl;

    if (qstrcmp(name,QAudioEncoderControl_iid) == 0)
        return m_encoderControl;

    if (qstrcmp(name,QAudioEndpointSelector_iid) == 0)
        return m_endpointSelector;
    
    if (qstrcmp(name,QMediaContainerControl_iid) == 0)
        return m_containerControl;

    return 0;
}

void S60AudioCaptureService::releaseControl(QMediaControl *control)
{
    Q_UNUSED(control)
}

==> qtmobility_1.2.0.orig.tar.gz: qt-mobility-opensource-src-1.2.0/plugins/multimedia/symbian/mmf/audiosource/s60audiocaptureservice.cpp <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Mobility Components.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "DebugMacros.h"
#include <QDebug>

#include "s60audiocaptureservice.h"
#include "s60audiocapturesession.h"
#include "s60audioendpointselector.h"
#include "s60audioencodercontrol.h"
#include "s60audiomediarecordercontrol.h"
#include "s60audiocontainercontrol.h"

S60AudioCaptureService::S60AudioCaptureService(QObject *parent):
    QMediaService(parent)
{
    DP0("S60AudioCaptureService::S60AudioCaptureService +++");

    m_session = new S60AudioCaptureSession(this);
    m_encoderControl = new S60AudioEncoderControl(m_session,this);
    m_recorderControl = new S60AudioMediaRecorderControl(m_session,this);
    m_endpointSelector = new S60AudioEndpointSelector(m_session,this); 
    m_containerControl = new S60AudioContainerControl(m_session, this);

    DP0("S60AudioCaptureService::S60AudioCaptureService ---");
}

S60AudioCaptureService::~S60AudioCaptureService()
{
    DP0("S60AudioCaptureService::~S60AudioCaptureService +++");
    DP0("S60AudioCaptureService::~S60AudioCaptureService ---");
}

QMediaControl *S60AudioCaptureService::requestControl(const char *name)
{
    DP0("S60AudioCaptureService::requestControl");

    if (qstrcmp(name,QMediaRecorderControl_iid) == 0)
        return m_recorderControl;

    if (qstrcmp(name,QAudioEncoderControl_iid) == 0)
        return m_encoderControl;

    if (qstrcmp(name,QAudioEndpointSelector_iid) == 0)
        return m_endpointSelector;
    
    if (qstrcmp(name,QMediaContainerControl_iid) == 0)
        return m_containerControl;

    return 0;
}

void S60AudioCaptureService::releaseControl(QMediaControl *control)
{
    DP0("S60AudioCaptureService::releaseControl +++");

    Q_UNUSED(control)

    DP0("S60AudioCaptureService::releaseControl ---");
}
